# zyx

ZYX is a simplicity-first library wrapped on top of Pydantic AI and heavily inspired by Marvin. It aims to provide a simple, stdlib-like interface for working with language models, without loss of control as well as flexibility that more complex frameworks provide.

## Installation

```bash
pip install zyx
```
